-- /dequip will unequip melee weapons, ranged weapons, shields, and class items. 
-- Inspired by Garan's Unequipper.

import "Turbine";
import "Turbine.Gameplay";

DequipCommand = class(Turbine.ShellCommand);

function DequipCommand:Execute(command, arguments)

	-- no arguments required.

	DequipCommand:UnequipItem(Turbine.Gameplay.Equipment.SecondaryWeapon);
	DequipCommand:UnequipItem(Turbine.Gameplay.Equipment.PrimaryWeapon);
	DequipCommand:UnequipItem(Turbine.Gameplay.Equipment.RangedWeapon);
	DequipCommand:UnequipItem(Turbine.Gameplay.Equipment.Class);

end

function DequipCommand:UnequipItem(slot)

	local player    = Turbine.Gameplay.LocalPlayer:GetInstance();
	local inventory = player:GetBackpack();
	local equipment = player:GetEquipment();
	local item      = equipment:GetItem(slot);

	if item == nil then
		return;
	end

	local i = 0;

	for i = 1, inventory:GetSize() do
		if inventory:GetItem(i) == nil then
			inventory:PerformItemDrop(item, i, false);
			return;
		end
	end

	Turbine.Shell.WriteLine("No room to unequip " .. item.GetName());
end

function DequipCommand:GetHelp()
	local helpText = "/dequip\n\nUnequips the character's secondary weapon (or shield), ranged weapon, ";
	helpText = helpText .. "primary weapon, and class item in that order.  Character must have enough ";
	helpText = helpText .. "empty space in inventory for unequipped items.";
	return(helpText);
end

function DequipCommand:GetShortHelp()
	return "Unequip weapons, shields, and class items."
end

-- Create instance and register.
dequip = DequipCommand();
Turbine.Shell.AddCommand("dequip", dequip);

